@@ -1,8 +1,8 @@
-/* $Id: gl.h,v 1.22 1997/11/19 03:12:46 brianp Exp $ */
+/* $Id: gl.h,v 1.26 1998/02/10 02:02:16 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.5
+ * Version:  2.6
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,18 @@
 
 /*
  * $Log: gl.h,v $
+ * Revision 1.26  1998/02/10 02:02:16  brianp
+ * changed a C++ style comment to C style
+ *
+ * Revision 1.25  1998/02/10 01:54:03  brianp
+ * added static library support for Win32 (Theodore Jump)
+ *
+ * Revision 1.24  1998/01/16 02:29:26  brianp
+ * minor changes for Windows compilation (Theodore Jump)
+ *
+ * Revision 1.23  1997/12/07 17:28:03  brianp
+ * updated version to 2.6
+ *
  * Revision 1.22  1997/11/19 03:12:46  brianp
  * added Stephane Rehel's cygnus patch
  *
@@ -102,9 +114,26 @@
 #endif
 
 
-#if (defined(FX) && defined(__WIN32__)) || defined(__CYGWIN32__)
+#if defined(__WIN32__) || defined(__CYGWIN32__)
 #include <windows.h>
 #pragma warning (disable:4273)
+#pragma warning( disable : 4244 ) /* '=' : conversion from 'const double ' to 'float ', possible loss of data */
+#pragma warning( disable : 4018 ) /* '<' : signed/unsigned mismatch */
+#pragma warning( disable : 4305 ) /* '=' : truncation from 'const double ' to 'float ' */
+#pragma warning( disable : 4013 ) /* 'function' undefined; assuming extern returning int */
+#pragma warning( disable : 4761 ) /* integral size mismatch in argument; conversion supplied */
+#pragma warning( disable : 4273 ) /* 'identifier' : inconsistent DLL linkage. dllexport assumed */
+#if (MESA_WARNQUIET>1)
+#	pragma warning( disable : 4146 ) /* unary minus operator applied to unsigned type, result still unsigned */
+#endif
+#if defined(_STATIC_MESA) /* for use with static link lib build of Win32 edition only */
+#undef APIENTRY
+#undef CALLBACK
+#undef WINGDIAPI
+#define APIENTRY __cdecl
+#define CALLBACK __cdecl
+#define WINGDIAPI extern
+#endif /* _STATIC_MESA support */
 #else
 #define APIENTRY
 #define CALLBACK
@@ -132,7 +161,7 @@ extern "C" {
 #define MESA
 
 #define MESA_MAJOR_VERSION 2
-#define MESA_MINOR_VERSION 5
+#define MESA_MINOR_VERSION 6
 
 
 #define GL_VERSION_1_1   1
