@@ -1,8 +1,8 @@
-/* $Id: nurbs.c,v 1.8 1997/09/17 01:51:48 brianp Exp $ */
+/* $Id: nurbs.c,v 1.11 1998/02/07 14:29:11 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.4
+ * Version:  2.6
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,15 @@
 
 /*
  * $Log: nurbs.c,v $
+ * Revision 1.11  1998/02/07 14:29:11  brianp
+ * fixed casting problem in gluNurbsCallback, again
+ *
+ * Revision 1.10  1998/02/04 00:21:20  brianp
+ * fixed cygnus compilation problem (Stephane Rehel)
+ *
+ * Revision 1.9  1998/01/16 03:35:26  brianp
+ * fixed Windows compilation warnings (Theodore Jump)
+ *
  * Revision 1.8  1997/09/17 01:51:48  brianp
  * changed glu*Callback() functions to match prototype in glu.h
  *
@@ -242,7 +251,7 @@ void APIENTRY gluGetNurbsProperty( GLUnurbsObj *nobj, GLenum property, GLfloat *
          *value = nobj->sampling_tolerance;
          break;
       case GLU_DISPLAY_MODE:
-         *value = (GLfloat) nobj->display_mode;
+         *value = (GLfloat) (GLint) nobj->display_mode;
          break;
       case GLU_CULLING:
          *value = nobj->culling ? 1.0 : 0.0;
@@ -581,7 +590,12 @@ void APIENTRY gluNurbsSurface( GLUnurbsObj *nobj,
 void APIENTRY
 gluNurbsCallback( GLUnurbsObj *nobj, GLenum which, void (CALLBACK *fn)())
 {
-    nobj->error_callback=fn;
+#ifdef __CYGWIN32__
+    nobj->error_callback = (void(*)(GLenum))fn;
+#else
+    nobj->error_callback = (void(CALLBACK*)(GLenum))fn;
+#endif
+
     if(which!=GLU_ERROR)
         call_user_error(nobj,GLU_INVALID_ENUM);
 }
