@@ -1,3 +1,4 @@
+
 /* Copyright (c) Mark J. Kilgard, 1994, 1995, 1996. */
 
 /* This program is freely distributable without licensing fees
@@ -15,10 +16,14 @@
 #include <sys/select.h> /* select system call interface */
 #endif
 #include <sys/types.h>
-#if !defined(WIN32) 
+#if !defined(WIN32)
+#if defined (__vms) && ( __VMS_VER < 70000000 )
+#include <sys/time.h>
+#else
 #ifndef __vms
 #include <sys/time.h>
 #endif
+#endif
 #include <unistd.h>
 #include <X11/Xlib.h>
 #include <X11/keysym.h>
@@ -27,7 +32,7 @@
 #include <sys/time.h>
 #else
 #include <sys/timeb.h>
-#endif
+#endif /*__CYGWIN32__*/
 #endif /* !WIN32 */
 #ifdef __hpux
 /* XXX Bert Gijsbers <bert@mc.bio.uva.nl> reports that HP-UX
@@ -36,7 +41,7 @@
    standard keysyms for standard keys. */
 #include <X11/HPkeysym.h>
 #endif
-#ifdef __vms
+#if defined(__vms) && ( __VMS_VER < 70000000 )
 #include <ssdef.h>
 #include <psldef.h>
 extern int SYS$CLREF(int efn);
@@ -89,7 +94,7 @@ glutTimerFunc(unsigned int interval, GLUTtimerCB timerFunc, int value)
   }
 
   timer->func = timerFunc;
-#ifdef __vms
+#if defined(__vms) && ( __VMS_VER < 70000000 )
   /* VMS time is expressed in units of 100 ns */
   timer->timeout.val = interval * TICKS_PER_MILLISECOND;
 #else
@@ -167,6 +172,16 @@ glutPostRedisplay(void)
   __glutPostRedisplay(__glutCurrentWindow, GLUT_REDISPLAY_WORK);
 }
 
+/* The advantage of this routine is that it saves the cost of a
+   glutSetWindow call (entailing an expensive OpenGL context switch),
+   particularly useful when multiple windows need redisplays posted at
+   the same times.  See also glutPostWindowOverlayRedisplay. */
+void APIENTRY
+glutPostWindowRedisplay(int win)
+{
+  __glutPostRedisplay(__glutWindowList[win - 1], GLUT_REDISPLAY_WORK);
+}
+
 /* ENDCENTRY */
 static GLUTeventParser *eventParserList = NULL;
 
@@ -268,19 +283,21 @@ interruptibleXNextEvent(Display * dpy, XEvent * event)
 static void
 processEventsAndTimeouts(void)
 {
-  XEvent event, ahead;
-  GLUTwindow *window;
-  int gotEvent, width, height;
-  GLUTeventParser *parser;
-
   do {
 #if defined(WIN32)
+    MSG event;
+
     if(!GetMessage(&event, NULL, 0, 0))	/* bail if no more messages */
       exit(0);
     TranslateMessage(&event);		/* translate virtual-key messages */
     DispatchMessage(&event);		/* call the window proc */
     /* see win32_event.c for event (message) processing procedures */
 #else
+    GLUTeventParser *parser;
+    XEvent event, ahead;
+    GLUTwindow *window;
+    int gotEvent, width, height;
+
     gotEvent = interruptibleXNextEvent(__glutDisplay, &event);
     if (gotEvent) {
       switch (event.type) {
@@ -312,12 +329,12 @@ processEventsAndTimeouts(void)
             window->reshape(width, height);
             window->forceReshape = False;
             /* A reshape should be considered like posting a
-               redisplay; this is necessary for the "Mesa
+               repair; this is necessary for the "Mesa
                glXSwapBuffers to repair damage" hack to operate
                correctly.  Without it, there's not an initial
                back buffer render from which to blit from when
                damage happens to the window. */
-            __glutPostRedisplay(window, GLUT_REDISPLAY_WORK);
+            __glutPostRedisplay(window, GLUT_REPAIR_WORK);
           }
         }
         break;
@@ -734,7 +751,7 @@ processEventsAndTimeouts(void)
 static void
 waitForSomething(void)
 {
-#ifdef __vms
+#if defined(__vms) && ( __VMS_VER < 70000000 )
   static struct timeval zerotime =
   {0};
   unsigned int timer_efn;
@@ -743,10 +760,14 @@ waitForSomething(void)
 #else
   static struct timeval zerotime =
   {0, 0};
+#if !defined(WIN32)
   fd_set fds;
+#endif
 #endif
   struct timeval now, timeout, waittime;
+#if !defined(WIN32)
   int rc;
+#endif
 
   /* Flush X protocol since XPending does not do this
      implicitly. */
@@ -763,7 +784,7 @@ waitForSomething(void)
        select. */
     goto immediatelyHandleXinput;
   }
-#ifdef __vms
+#if defined(__vms) && ( __VMS_VER < 70000000 )
   timeout = __glutTimerList->timeout;
   GETTIMEOFDAY(&now);
   wait_mask = 1 << (__glutConnectionFD & 31);
@@ -788,7 +809,7 @@ waitForSomething(void)
   }
   /* XXX There does not seem to be checking of "rc" in the code
      above.  Can any of the SYS$ routines above fail? */
-#else /* not vms */
+#else /* not vms6.2 or lower */
 #if !defined(WIN32)
   FD_ZERO(&fds);
   FD_SET(__glutConnectionFD, &fds);
@@ -806,16 +827,18 @@ waitForSomething(void)
   if (rc < 0 && errno != EINTR)
     __glutFatalError("select error.");
 #else
-  /* set up a timer to fire in at least a millisecond, then wait for
+#if 0 /* XXX Nate, what is this junk? */
+  /* Set up a timer to fire in at least a millisecond, then wait for
      the message.  This should act like a select. */
-//    SetTimer(NULL, 2, waittime.tv_usec, NULL);
-//    WaitMessage();
-//    KillTimer(NULL, 2);
+  SetTimer(NULL, 2, waittime.tv_usec, NULL);
+  WaitMessage();
+  KillTimer(NULL, 2);
+#endif
 
-  /* actually, a sleep seems to do the trick -- do we even need this? */
+  /* Actually, a sleep seems to do the trick -- do we even need this? */
   Sleep(0);
 #endif
-#endif /* not vms */
+#endif /* not vms6.2 or lower */
   /* Without considering the cause of select unblocking, check
      for pending X events and handle any timeouts (by calling
      processEventsAndTimeouts).  We always look for X events
@@ -923,12 +946,13 @@ processWindowWorkList(GLUTwindow * window)
 #if defined(WIN32)
       RECT changes;
       POINT point;
-      int stack_mode;
+      UINT flags = SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOOWNERZORDER
+	| SWP_NOSENDCHANGING | SWP_NOSIZE | SWP_NOZORDER;
 
       GetClientRect(window->win, &changes);
       
-      // if this window is a toplevel window, translate the 0,0 client
-      // coordinate into a screen coordinate for proper placement
+      /* If this window is a toplevel window, translate the 0,0 client
+         coordinate into a screen coordinate for proper placement. */
       if (!window->parent) {
         point.x = 0;
         point.y = 0;
@@ -939,57 +963,41 @@ processWindowWorkList(GLUTwindow * window)
       if (window->desiredConfMask & (CWX | CWY)) {
         changes.left = window->desiredX;
         changes.top = window->desiredY;
+	flags &= ~SWP_NOMOVE;
       }
       if (window->desiredConfMask & (CWWidth | CWHeight)) {
         changes.right = changes.left + window->desiredWidth;
         changes.bottom = changes.top + window->desiredHeight;
-	//         if (window->overlay)
-	//           XResizeWindow(__glutDisplay, window->overlay->win,
-	//             window->desiredWidth, window->desiredHeight);
+	flags &= ~SWP_NOSIZE;
+	/* XXX If overlay exists, resize the overlay here, ie.
+	   if (window->overlay) ... */
       }
       if (window->desiredConfMask & CWStackMode) {
-        stack_mode = window->desiredStack;
-        /* Do not let glutPushWindow push window beneath the
-           underlay. */
-        if (window->parent && window->parent->overlay && window->desiredStack == Below) {
-          stack_mode = Above;
-        }
+	flags &= ~SWP_NOZORDER;
+	/* XXX Overlay support might require something special here. */
       }
       
-      // adjust the window rectangle because Win32 thinks that the x, y,
-      // width & height are the WHOLE window (including decorations),
-      // whereas GLUT treats the x, y, width & height as only the CLIENT
-      // area of the window.  ONLY DO THIS IF TOPLEVEL WINDOW.
+      /* Adjust the window rectangle because Win32 thinks that the x, y,
+         width & height are the WHOLE window (including decorations),
+         whereas GLUT treats the x, y, width & height as only the CLIENT
+         area of the window.  ONLY DO THIS IF TOPLEVEL WINDOW. */
       if (!window->parent) {
         AdjustWindowRect(&changes,
           WS_OVERLAPPEDWINDOW | WS_CLIPSIBLINGS | WS_CLIPCHILDREN,
           FALSE);
-#if 0
-        // readjust if the x and y are offscreen
-        if (changes.left < 0) {
-          changes.right = changes.right - changes.left;
-          changes.left = 0;
-        }
-        if (changes.top < 0) {
-          changes.bottom = changes.bottom - changes.top;
-          changes.top = 0;
-        }
-#endif
       }
-      // do the repositioning and moving
-      SetWindowPos(window->win, 0, changes.left, changes.top,
+      /* Do the repositioning, moving, and push/pop. */
+      SetWindowPos(window->win,
+        window->desiredStack == Above ? HWND_TOP : HWND_NOTOPMOST,
+        changes.left, changes.top,
         changes.right - changes.left, changes.bottom - changes.top,
-        SWP_NOZORDER);
+        flags);
 
-      // do the Z ordering.
-      SetWindowPos(window->win, stack_mode == Above ? HWND_TOP : HWND_NOTOPMOST,
-        0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE | SWP_NOREPOSITION);
-
-      // zero out the mask
+      /* Zero out the mask. */
       window->desiredConfMask = 0;
       
-      // this hack causes the window to go back to the right position
-      // when it is taken out of fullscreen mode.
+      /* This hack causes the window to go back to the right position
+         when it is taken out of fullscreen mode. */
       if (workMask & GLUT_FULL_SCREEN_WORK) {
         window->desiredConfMask |= CWX | CWY;
         window->desiredX = point.x;
@@ -1047,7 +1055,8 @@ processWindowWorkList(GLUTwindow * window)
         changes.stack_mode = window->desiredStack;
         /* Do not let glutPushWindow push window beneath the
            underlay. */
-        if (window->parent && window->parent->overlay && window->desiredStack == Below) {
+        if (window->parent && window->parent->overlay
+          && window->desiredStack == Below) {
           changes.stack_mode = Above;
           changes.sibling = window->parent->overlay->win;
           window->desiredConfMask |= CWSibling;
@@ -1058,11 +1067,13 @@ processWindowWorkList(GLUTwindow * window)
       window->desiredConfMask = 0;
 #endif
     }
+#if !defined(WIN32)
     /* Be sure to establish the colormaps BEFORE map window is
        done. */
     if (workMask & GLUT_COLORMAP_WORK) {
       __glutEstablishColormapsProperty(window);
     }
+#endif
     if (workMask & GLUT_MAP_WORK) {
       switch (window->desiredMapState) {
       case WithdrawnState:
