@@ -1,8 +1,8 @@
-/* $Id: matrix.c,v 1.22 1997/10/16 23:37:23 brianp Exp $ */
+/* $Id: matrix.c,v 1.23 1997/12/29 23:48:53 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.5
+ * Version:  2.6
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,9 @@
 
 /*
  * $Log: matrix.c,v $
+ * Revision 1.23  1997/12/29 23:48:53  brianp
+ * call Driver.NearFar() in gl_LoadMatrixf() for projection matrix
+ *
  * Revision 1.22  1997/10/16 23:37:23  brianp
  * fixed scotter's email address
  *
@@ -747,6 +750,27 @@ void gl_LoadMatrixf( GLcontext *ctx, const GLfloat *m )
       case GL_PROJECTION:
 	 MEMCPY( ctx->ProjectionMatrix, m, 16*sizeof(GLfloat) );
 	 ctx->NewProjectionMatrix = GL_TRUE;
+         {
+            float n,f,c,d;
+
+#define M(row,col)  m[col*4+row]
+            c = M(2,2);
+            d = M(2,3);
+#undef M
+            n = d / (c-1);
+            f = d / (c+1);
+
+            /* Need to keep a stack of near/far values in case the user
+             * push/pops the projection matrix stack so that we can call
+             * Driver.NearFar() after a pop.
+             */
+            ctx->NearFarStack[ctx->ProjectionStackDepth][0] = n;
+            ctx->NearFarStack[ctx->ProjectionStackDepth][1] = f;
+
+            if (ctx->Driver.NearFar) {
+               (*ctx->Driver.NearFar)( ctx, n, f );
+            }
+         }
 	 break;
       case GL_TEXTURE:
 	 MEMCPY( ctx->TextureMatrix, m, 16*sizeof(GLfloat) );
