@@ -1,4 +1,4 @@
-/* $Id: varray.c,v 1.16 1997/08/14 01:15:47 brianp Exp $ */
+/* $Id: varray.c,v 1.17 1998/02/03 01:40:45 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
@@ -23,6 +23,9 @@
 
 /*
  * $Log: varray.c,v $
+ * Revision 1.17  1998/02/03 01:40:45  brianp
+ * fixed a few expressions for Amiga compilation (Sam Jordan)
+ *
  * Revision 1.16  1997/08/14 01:15:47  brianp
  * gl_ArrayElement()'s assignment of current normal was wrong
  *
@@ -825,7 +828,8 @@ void gl_DrawArrays( GLcontext *ctx,
       gl_Begin( ctx, mode );
 
       remaining = count;
-      vptr = (GLfloat (*)[3]) ctx->Array.VertexPtr + 3 * first;
+      vptr = (GLfloat (*)[3]) ctx->Array.VertexPtr;
+      vptr += 3 * first;
       while (remaining>0) {
          GLint vbspace, n;
 
@@ -881,8 +885,10 @@ void gl_DrawArrays( GLcontext *ctx,
       gl_Begin( ctx, mode );
 
       remaining = count;
-      vptr = (GLfloat (*)[4]) ctx->Array.VertexPtr + 4 * first;
-      nptr = (GLfloat (*)[3]) ctx->Array.NormalPtr + 3 * first;
+      vptr = (GLfloat (*)[4]) ctx->Array.VertexPtr;
+      vptr += 4 * first;
+      nptr = (GLfloat (*)[3]) ctx->Array.NormalPtr;
+      nptr += 3 * first;
       while (remaining>0) {
          GLint vbspace, n;
 
@@ -933,8 +939,10 @@ void gl_DrawArrays( GLcontext *ctx,
       gl_Begin( ctx, mode );
 
       remaining = count;
-      vptr = (GLfloat (*)[3]) ctx->Array.VertexPtr + 3 * first;
-      nptr = (GLfloat (*)[3]) ctx->Array.NormalPtr + 3 * first;
+      vptr = (GLfloat (*)[3]) ctx->Array.VertexPtr;
+      vptr += 3 * first;
+      nptr = (GLfloat (*)[3]) ctx->Array.NormalPtr;
+      nptr += 3 * first;
       while (remaining>0) {
          GLint vbspace, n;
 
