@@ -1,8 +1,8 @@
-/* $Id: xmesaP.h,v 1.20 1997/09/10 00:05:33 brianp Exp $ */
+/* $Id: xmesaP.h,v 1.21 1998/01/27 03:28:25 brianp Exp $ */
 
 /*
  * Mesa 3-D graphics library
- * Version:  2.4
+ * Version:  2.6
  * Copyright (C) 1995-1997  Brian Paul
  *
  * This library is free software; you can redistribute it and/or
@@ -23,6 +23,9 @@
 
 /*
  * $Log: xmesaP.h,v $
+ * Revision 1.21  1998/01/27 03:28:25  brianp
+ * added XMesaSetFXmode()
+ *
  * Revision 1.20  1997/09/10 00:05:33  brianp
  * undefine _R, _G and _B symbols to prevent compiler warnings
  *
@@ -163,8 +166,8 @@ struct xmesa_context {
 	unsigned long clearpixel;	/* current clearing pixel value */
 
 #ifdef FX
-	GLboolean FXuse;	/* Use 3Dfx Glide for rendering ? */
-	GLboolean FXhack;	/* Use 3Dfx Glide for rendering into X win? */
+	GLboolean FXisHackUsable;	/* Is 3Dfx Glide for rendering into X win possible ? */
+	GLboolean FXwindowHack;	        /* Use 3Dfx Glide for rendering into X win ? */
 	fxMesaContext FXctx;
 #endif
 };
